@@ -11,7 +11,7 @@ def controllerclass(name):
         controller = imp.load_module(name, fp, pathname, description)
         return controller.info["class"]
     finally:
-        if fp != None: fp.close
+        if fp != None: fp.close()
 
 class Controller(object):
     "Controllers take data from some files, do stuff with it, and write it to the build directory."
@@ -27,3 +27,10 @@ class Controller(object):
     def __call__(self):
         # do whatever needs to be done here...
         pass
+
+    def template(self, name):
+        "Given a name, return the name of the file in the templates directory that fits it."
+        # list of files that fit:
+        files = [f for f in os.listdir(self.templates_directory) if f.startswith(name + ".")]
+        # return the first file that matches, with the directory prepended.
+        return os.path.join(self.templates_directory, files[0])
